@@ -528,6 +528,39 @@ RBS
     assert_equal type_name("::Foo::Bar::Baz"), env.normalize_module_name(type_name("::N"))
   end
 
+  def test_normalize_module_name_q
+    buf, dirs, decls = RBS::Parser.parse_signature(<<~EOF)
+      class Foo
+        module Bar
+          module Baz
+          end
+        end
+      end
+
+      module M = Foo::Bar
+      module N = M::Baz
+
+      module C = D
+      module D = C
+
+      module E = F
+    EOF
+
+    env = Environment.new()
+    env.add_signature(buffer: buf, directives: dirs, decls: decls)
+
+    env = env.resolve_type_names
+
+    assert_equal type_name("::Foo::Bar"), env.normalize_module_name?(type_name("::M"))
+    assert_equal type_name("::Foo::Bar::Baz"), env.normalize_module_name?(type_name("::N"))
+
+    assert_equal false, env.normalize_module_name?(type_name("::C"))
+    assert_equal false, env.normalize_module_name?(type_name("::D"))
+
+    assert_nil env.normalize_module_name?(type_name("::E"))
+  end
+
+
   def test_use_resolve
     buf, dirs, decls = RBS::Parser.parse_signature(<<-RBS)
 use Object as OB
@@ -585,4 +618,32 @@ type s = untyped
       assert_equal "::s", alias_decl.decl.type.to_s
     end
   end
+
+  def test_resolve_type_names_module_alias
+    buf, dirs, decls = RBS::Parser.parse_signature(<<-RBS)
+module M
+  module N
+  end
+
+  module N2 = N
+end
+
+class C
+  include M::N2
+end
+    RBS
+
+    env = Environment.new
+    env.add_signature(buffer: buf, directives: dirs, decls: decls)
+
+    env.resolve_type_names.tap do |env|
+      class_decl = env.class_decls[RBS::TypeName.parse("::C")]
+      class_decl.decls.each do |d|
+        d.decl.members[0].tap do |member|
+          assert_instance_of RBS::AST::Members::Include, member
+          assert_equal RBS::TypeName.parse("::M::N"), member.name
+        end
+      end
+    end
+  end
 end
