@@ -8,8 +8,8 @@ class RBS::NodeUsageTest < Test::Unit::TestCase
   end
 
   def test_conditional
-    usage = NodeUsage.new(parse(<<~RB))
-      if block
+    NodeUsage.new(parse(<<~RB))
+      def block
         yield
       end
 
