@@ -655,13 +655,14 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
   end
 
   def test_record
-    Parser.parse_type("{ foo: untyped, 3 => 'hoge' }").yield_self do |type|
+    Parser.parse_type("{ foo: untyped, 3 => 'hoge', 4 => 'huge' }").yield_self do |type|
       assert_instance_of Types::Record, type
       assert_equal({
                      foo: Types::Bases::Any.new(location: nil),
-                     3 => Types::Literal.new(literal: "hoge", location: nil)
+                     3 => Types::Literal.new(literal: "hoge", location: nil),
+                     4 => Types::Literal.new(literal: "huge", location: nil),
                    }, type.fields)
-      assert_equal "{ foo: untyped, 3 => 'hoge' }", type.location.source
+      assert_equal "{ foo: untyped, 3 => 'hoge', 4 => 'huge' }", type.location.source
     end
 
     Parser.parse_type("{}").yield_self do |type|
@@ -882,4 +883,40 @@ class RBS::TypeParsingTest < Test::Unit::TestCase
       assert_equal "\x00", type.types[2].literal
     end
   end
+
+  def test_parse__string_octal_escape
+    Parser.parse_type('"\100"').yield_self do |type|
+      assert_equal "\100", type.literal
+    end
+    Parser.parse_type('"\400"').yield_self do |type|
+      assert_equal "\400", type.literal
+    end
+  end
+
+  def test_parse__string_hex_escape
+    Parser.parse_type('"\x10"').yield_self do |type|
+      assert_equal "\x10", type.literal
+    end
+    Parser.parse_type('"\x40"').yield_self do |type|
+      assert_equal "\x40", type.literal
+    end
+  end
+
+  def test_parse__string_unicode_escape
+    Parser.parse_type('"\u005a"').yield_self do |type|
+      assert_equal "Z", type.literal
+    end
+    Parser.parse_type('"[\u30eb]"').yield_self do |type|
+      assert_equal "[ル]", type.literal
+    end
+  end
+
+  def test_parse__string_unicode_escape__non_unicode
+    Parser.parse_type('"\u005a"'.encode(Encoding::ASCII)).yield_self do |type|
+      assert_equal "\\u005a", type.literal
+    end
+    Parser.parse_type('"[\u30eb]"'.encode(Encoding::Shift_JIS)).yield_self do |type|
+      assert_equal "[\\u30eb]", type.literal
+    end
+  end
 end
