@@ -2,7 +2,7 @@ require_relative "test_helper"
 require "socket"
 
 class FileSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   testing "singleton(::File)"
 
@@ -353,12 +353,16 @@ class FileSingletonTest < Test::Unit::TestCase
   end
 
   def test_join
-    assert_send_type "(String) -> String",
-                     File, :join, "foo"
-    assert_send_type "(ToStr) -> String",
-                     File, :join, ToStr.new("foo")
-    assert_send_type "(String, String) -> String",
-                     File, :join, "foo", "bar"
+    with_path("foo") do |str|
+      assert_send_type(
+        "(path) -> String",
+        File, :join, str
+      )
+      assert_send_type(
+        "(path, path) -> String",
+        File, :join, str, str
+      )
+    end
   end
 
   def test_lchown
@@ -381,17 +385,26 @@ class FileSingletonTest < Test::Unit::TestCase
   end
 
   def test_link
-    assert_send_type "(String, String) -> 0",
-                     File, :link, File.expand_path(__FILE__), "new_name"
-    File.unlink("new_name")
+    begin
+      assert_send_type "(String, String) -> 0",
+                       File, :link, File.expand_path(__FILE__), "new_name"
+    ensure
+      File.unlink("new_name")
+    end
 
-    assert_send_type "(ToStr, ToStr) -> 0",
-                     File, :link, ToStr.new(File.expand_path(__FILE__)), ToStr.new("new_name")
-    File.unlink("new_name")
+    begin
+      assert_send_type "(ToStr, ToStr) -> 0",
+                       File, :link, ToStr.new(File.expand_path(__FILE__)), ToStr.new("new_name")
+    ensure
+      File.unlink("new_name")
+    end
 
-    assert_send_type "(ToPath, ToPath) -> 0",
-                     File, :link, ToPath.new(File.expand_path(__FILE__)), ToPath.new("new_name")
-    File.unlink("new_name")
+    begin
+      assert_send_type "(ToPath, ToPath) -> 0",
+                       File, :link, ToPath.new(File.expand_path(__FILE__)), ToPath.new("new_name")
+    ensure
+      File.unlink("new_name")
+    end
   end
 
   def test_lstat
@@ -839,7 +852,7 @@ class FileSingletonTest < Test::Unit::TestCase
 end
 
 class FileInstanceTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   testing "::File"
 
