@@ -458,26 +458,6 @@ class IOWaitTest < Test::Unit::TestCase
 
   testing "::IO"
 
-  def test_readyp
-    # This method returns true|false in Ruby 2.7, nil|IO in 3.0, and true|false in 3.1.
-
-    IO.pipe.tap do |r, w|
-      assert_send_type(
-        "() -> untyped",
-        r, :ready?
-      )
-    end
-
-    IO.pipe.tap do |r, w|
-      w.write("hello")
-
-      assert_send_type(
-        "() -> untyped",
-        r, :ready?
-      )
-    end
-  end
-
   def test_wait_readable
     if_ruby "3.0.0"..."3.2.0" do
       IO.pipe.tap do |r, w|
@@ -516,15 +496,6 @@ class IOWaitTest < Test::Unit::TestCase
     end
   end
 
-  def test_nread
-    IO.pipe.tap do |r, w|
-      assert_send_type(
-        "() -> Integer",
-        r, :nread
-      )
-    end
-  end
-
   def test_wait
     if_ruby "3.0.0"..."3.2.0", skip: false do
       IO.pipe.tap do |r, w|
