@@ -2,8 +2,8 @@ require_relative "test_helper"
 require 'pathname'
 
 class PathnameSingletonTest < Test::Unit::TestCase
-  include TypeAssertions
-  library 'pathname'
+  include TestHelper
+
   testing 'singleton(::Pathname)'
 
   def test_getwd
@@ -27,19 +27,19 @@ class PathnameSingletonTest < Test::Unit::TestCase
                      Pathname, :pwd
   end
 
-  def test_initialize
+  def test_new
     assert_send_type '(String) -> Pathname',
                      Pathname, :new, 'foo'
     assert_send_type '(ToStr) -> Pathname',
-                     Pathname, :new, ToStr.new('foo')
+                     Pathname, :new, ToStr.new('foo').__with_object_methods(:respond_to?)
     assert_send_type '(Pathname) -> Pathname',
                      Pathname, :new, Pathname('foo')
   end
 end
 
 class PathnameInstanceTest < Test::Unit::TestCase
-  include TypeAssertions
-  library 'pathname'
+  include TestHelper
+
   testing '::Pathname'
 
   def test_plus
@@ -48,7 +48,7 @@ class PathnameInstanceTest < Test::Unit::TestCase
     assert_send_type '(String) -> Pathname',
                      Pathname('foo'), :+, 'bar'
     assert_send_type '(ToStr) -> Pathname',
-                     Pathname('foo'), :+, ToStr.new('bar')
+                     Pathname('foo'), :+, ToStr.new('bar').__with_object_methods(:respond_to?)
   end
 
   def test_slash
@@ -57,7 +57,7 @@ class PathnameInstanceTest < Test::Unit::TestCase
     assert_send_type '(String) -> Pathname',
                      Pathname('foo'), :/, 'bar'
     assert_send_type '(ToStr) -> Pathname',
-                     Pathname('foo'), :/, ToStr.new('bar')
+                     Pathname('foo'), :/, ToStr.new('bar').__with_object_methods(:respond_to?)
   end
 
   def test_spaceship
@@ -387,7 +387,7 @@ class PathnameInstanceTest < Test::Unit::TestCase
     assert_send_type '(String, String) -> Pathname',
                      Pathname('.'), :join, 'foo', 'bar'
     assert_send_type '(ToStr) -> Pathname',
-                     Pathname('.'), :join, ToStr.new('foo')
+                     Pathname('.'), :join, ToStr.new('foo').__with_object_methods(:respond_to?)
     assert_send_type '(Pathname) -> Pathname',
                      Pathname('.'), :join, Pathname('foo')
   end
@@ -461,8 +461,8 @@ class PathnameInstanceTest < Test::Unit::TestCase
     Dir.mktmpdir do |dir|
       dir = Pathname(dir)
 
-      assert_send_type '() -> nil',
-                       dir + 'a/b/c', :mkpath
+      assert_send_type '() -> Pathname',
+                        dir + 'a/b/c', :mkpath
     end
   end
 
@@ -606,8 +606,9 @@ class PathnameInstanceTest < Test::Unit::TestCase
                      Pathname('.'), :relative_path_from, Pathname('.')
     assert_send_type '(String) -> Pathname',
                      Pathname('.'), :relative_path_from, '.'
-    assert_send_type '(ToStr) -> Pathname',
-                     Pathname('.'), :relative_path_from, ToStr.new('.')
+
+    assert_send_type '(_ToStr) -> Pathname',
+                     Pathname('.'), :relative_path_from, ToStr.new('.').__with_object_methods(:is_a?, :respond_to?)
   end
 
   def test_rename
@@ -641,7 +642,7 @@ class PathnameInstanceTest < Test::Unit::TestCase
     Dir.mktmpdir do |dir|
       target = Pathname(dir).join('target')
       target.mkdir
-      assert_send_type '() -> void',
+      assert_send_type '() -> Pathname',
                        target, :rmtree
     end
   end
@@ -731,8 +732,10 @@ class PathnameInstanceTest < Test::Unit::TestCase
   end
 
   def test_taint
-    assert_send_type '() -> Pathname',
-                     Pathname(File.expand_path(__FILE__)), :taint
+    if Pathname.method_defined?(:taint)
+      assert_send_type '() -> Pathname',
+                      Pathname(File.expand_path(__FILE__)), :taint
+    end
   end
 
   def test_to_path
@@ -759,8 +762,10 @@ class PathnameInstanceTest < Test::Unit::TestCase
   end
 
   def test_untaint
-    assert_send_type '() -> Pathname',
-                     Pathname(File.expand_path(__FILE__)), :untaint
+    if Pathname.method_defined?(:untaint)
+      assert_send_type '() -> Pathname',
+                      Pathname(File.expand_path(__FILE__)), :untaint
+    end
   end
 
   def test_utime
@@ -812,3 +817,26 @@ class PathnameInstanceTest < Test::Unit::TestCase
                      Pathname(File.expand_path(__FILE__)), :zero?
   end
 end
+
+class PathnameKernelTest < Test::Unit::TestCase
+  include TestHelper
+
+  testing '::Kernel'
+
+  def test_Pathname
+    assert_send_type(
+      "(::String) -> ::Pathname",
+      self, :Pathname, "Gemfile"
+    )
+
+    assert_send_type(
+      "(::_ToStr) -> ::Pathname",
+      self, :Pathname, ToStr.new("Gemfile").__with_object_methods(:respond_to?)
+    )
+
+    assert_send_type(
+      "(::Pathname) -> ::Pathname",
+      self, :Pathname, Pathname.pwd
+    )
+  end
+end
