@@ -1,7 +1,7 @@
 require_relative "test_helper"
 
 class SetTest < Test::Unit::TestCase
-  include TypeAssertions
+  include TestHelper
 
   testing "::Set[::Integer]"
 
